# ПРИМЕР НАСТРОЙКИ МОДУЛЯ:
                                                #
from pyiArduinoI2Ctds import *                  #   Подключаем библиотеку для работы с TDS/EC-метром I2C-flash.
tds = pyiArduinoI2Ctds(0x09)                    #   Объявляем объект tds  для работы с функциями и методами библиотеки pyiArduinoI2Ctds, указывая адрес модуля на шине I2C.
                                                #   Если объявить объект без указания адреса (pyiArduinoI2Ctds tds ), то адрес будет найден автоматически.
tds.setFrequency(  2000)                        #   Устанавливаем частоту переменного тока для измерений от 50 до 5000 Гц. Значение сохраняется в энергонезависимую память.
tds.setKnownTDS (1, 500)                        #   Устанавливаем концентрацию 1 раствора для калибровки модуля с кнопки.  Значение сохраняется в энергонезависимую память.
tds.setKnownTDS (2,1500)                        #   Устанавливаем концентрацию 2 раствора для калибровки модуля с кнопки.  Значение сохраняется в энергонезависимую память.
tds.setKt       (  0.02)                        #   Устанавливаем температурный коэффициент жидкости от 0,0000 до 6,5535.
tds.setKp       (  0.50)                        #   Устанавливаем коэффициент пересчёта от 0,01 до 2,55.
tds.set_T       ( 25.00)                        #   Устанавливаем опорную температуру жидкости от 0,00 до 63,75 °С.
