# ПРИМЕР ПОЛУЧЕНИЯ ДАННЫХ ПО ШИНЕ I2C:
                                                  #
from time import sleep
from pyiArduinoI2Ctds import *                    #   Подключаем библиотеку для работы с TDS/EC-метром I2C-flash.
tds = pyiArduinoI2Ctds(0x09)                      #   Объявляем объект tds  для работы с функциями и методами библиотеки pyiArduinoI2Ctds, указывая адрес модуля на шине I2C.
                                                  #   Если объявить объект без указания адреса (pyiArduinoI2Ctds tds ), то адрес будет найден автоматически.
while True:                                       #
     tds.set_t(22.5)                              #   Указываем текущую температуру жидкости.
     print("Ro="          , end='')               #
     print(tds.getRo()    , end='')               #   Выводим общее измеренное сопротивление.
     print("Ом, S="       , end='')               #
     print(tds.get_S()    , end='')               #   Выводим измеренную удельную электропроводность жидкости.
     print("мкСм/см, EC=" , end='')               #
     print(tds.getEC()    , end='')               #   Выводим удельную электропроводность жидкости приведённую к опорной температуре.
     print("мкСм/см, TDS=", end='')               #
     print(tds.getTDS()   , end='')               #   Выводим количество растворённых твёрдых веществ в жидкости.
     print(" мг/л\r\n"    , end='')               #
     sleep(1)                                     #
